%define _requires_exceptions perl(LWP::Parallel::UserAgent)

Summary:	Filter, redirector and access controller plugin for Squid
Name:		squidGuard
Version:	1.2.1
Release:	%mkrel 2
License:	GPL
Group:		System/Servers
URL:		http://www.squidguard.org
Source0:	http://www.squidguard.org/Downloads/%{name}-%{version}.tar.gz
Source1:	%{name}.conf.sample
Source2:	blacklists-readme
Source3:	%{name}.cgi
Source4:	nulbanner.png
Source5:	blacklist-update
Source6:	%{name}.logrotate
Patch0:		squidGuard-1.2.0.default_dir.patch
Patch1:		squidGuard-no_doc.diff
Patch2:		squidGuard-upstream_bugfixes.diff
BuildRequires:	bison 
BuildRequires:	db4-devel
BuildRequires:	flex
BuildRequires:	openldap-devel
Requires:	squid 
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root

%description
SquidGuard is a combined filter, redirector and access controller plugin for
Squid. It is free, very flexible, extremely fast, easily installed, portable.
SquidGuard can be used to 
- limit the web access for some users to a list of accepted/well known web
servers and/or URLs only. 
- block access to some listed or blacklisted web servers and/or URLs for
some users. 
- block access to URLs matching a list of regular expressions or words for
some users. 
- enforce the use of domainnames/prohibit the use of IP address in URLs. 
- redirect blocked URLs to an "intelligent" CGI based info page.
- redirect unregistered user to a registration form. 
- redirect popular downloads like Netscape, MSIE etc. to local copies. 
- redirect banners to an empty GIF.
- have different access rules based on time of day, day of the week, date
etc. 
- have different rules for different user groups. 

Neither squidGuard nor Squid can be used to 

- filter/censor/edit text inside documents 
- filter/censor/edit embeded scripting languages 
  like JavaScript or VBscript inside HTML 


%prep

%setup -q
%patch0 -p1
%patch1 -p0
%patch2 -p1

cp %{SOURCE6} %{name}.logrotate

%build
%serverbuild

%configure2_5x \
    --with-ldap \
    --with-sg-config=%{_sysconfdir}/squid/%{name}.conf \
    --with-sg-logdir=/var/log/squidGuard \
    --with-sg-dbhome=%{_datadir}/%{name}-%{version}/db

%make

%install
rm -rf %{buildroot}

P=$RPM_BUILD_DIR/%{name}-%{version}
Q=%{buildroot}/%{_datadir}/%{name}-%{version}

%makeinstall SQUIDUSER="`id -nu`" MAKEDEFS=' \
  "logdir=%{buildroot}/var/log/squidGuard" \
  "cfgdir=%{buildroot}%{_sysconfdir}/squid"'

mkdir -p $Q/{contrib,samples,log}
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -m0644 %{name}.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# the mandrake default config directories
mkdir -p $Q/db/{advertising,bannedsource,banneddestination}
mkdir -p $Q/db/{timerestriction,lansource,privilegedsource}

touch $Q/db/advertising/{domains,urls}
touch $Q/db/banneddestination/{domains,urls,expressions}
touch $Q/db/bannedsource/ips
touch $Q/db/lansource/lan
touch $Q/db/timerestriction/lan
touch $Q/db/privilegedsource/ips

# the blacklists default directories (Fabrice Pringent's one)
mkdir -p $Q/db/{porn,adult,audio-video,forums,hacking,redirector}
mkdir -p $Q/db/{warez,ads,aggressive,drugs,gambling,publicite,violence}
touch $Q/db/porn/{domains,urls,expressions}
touch $Q/db/adult/{domains,urls,expressions}
touch $Q/db/audio-video/{domains,urls}
touch $Q/db/forums/{domains,urls,expressions}
touch $Q/db/hacking/{domains,urls}
touch $Q/db/redirector/{domains,urls,expressions}
touch $Q/db/warez/{domains,urls}
touch $Q/db/ads/{domains,urls}
touch $Q/db/aggressive/{domains,urls}
touch $Q/db/drugs/{domains,urls}
touch $Q/db/gambling/{domains,urls}
touch $Q/db/publicite/{domains,urls,expressions}
touch $Q/db/violence/{domains,urls,expressions}

cd $P/samples/dest/
tar xzf blacklists.tar.gz
cp -af blacklists/* $Q/db
cd -

cp -a $P/contrib/hostbyname/hostbyname $Q/contrib/
cp -a $P/contrib/sgclean/sgclean $Q/contrib/
cp -a $P/contrib/squidGuardRobot/{squidGuardRobot,RobotUserAgent.pm} $Q/contrib/

cp -a $P/samples/dest $Q/samples
cp -a $P/samples/*{.conf,.cgi} $Q/samples
cp -a %{SOURCE2} $P/
cp -a %{SOURCE5} $P/

rm -rf $Q/test/test*.conf.*

# default config files
#log & error files
mkdir -p %{buildroot}/var/log/%{name}
touch %{buildroot}/var/log/%{name}/%{name}.{log,error}
touch %{buildroot}/var/log/%{name}/advertising.log

#conf file
mkdir -p %{buildroot}/etc/squid
mkdir -p %{buildroot}/var/www/cgi-bin
install %{SOURCE1} %{buildroot}/etc/squid/%{name}.conf.sample
cp -af %{SOURCE3} %{SOURCE4} %{buildroot}/var/www/cgi-bin
rm -rf %{buildroot}%{_datadir}/%{name}-%{version}/samples/dest

# cleanup
rm -rf %{buildroot}%{_prefix}/squidGuard

%preun
if [ $1 = 0 ] ; then
        rm -f /var/log/squidGuard/*
fi

%post
rm -rf `find %{_datadir}/%{name}-%{version}/db |grep "\.db"`
%{_bindir}/%{name} -c  %{_sysconfdir}/squid/%{name}.conf.sample -C all 
for i in privilegedsource bannedsource timerestriction lansource banneddestination advertising; do
    rm -rf /usr/share/%{name}-%{version}/db/$i/*.db 
done
chown -R squid.squid /usr/share/%{name}-%{version}/db

echo "WARNING !!! WARNING !!! WARNING !!! WARNING !!!"
echo ""
echo "Modify the following line in the /etc/squid/squid.conf file:"
echo "redirect_program /usr/bin/squidGuard -c /etc/squid/squidGuard.conf"

%postun
if [ "$1" = "0" ]; then
    rm -rf %{_datadir}/%{name}-%{version}
fi

%triggerun -- squidGuard <= 1.2.0-13mdv2007.1
mv %{_datadir}/%{name}-%{version} %{_datadir}/%{name}-%{version}.bk

%triggerpostun -- squidGuard <= 1.2.0-13mdv2007.1
mv %{_datadir}/%{name}-%{version}.bk %{_datadir}/%{name}-%{version}

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc README README.LDAP ANNOUNCE GPL COPYING CHANGELOG blacklists-readme doc/*.{html,gif,txt}
%{_bindir}/*
%attr(0644,root,root) %{_datadir}/%{name}-%{version}/contrib/*
%attr(0644,root,root) %{_datadir}/%{name}-%{version}/samples/*.conf
%attr(0644,root,root) %{_datadir}/%{name}-%{version}/samples/*.cgi
%attr(0755,apache,apache) /var/www/cgi-bin/*.cgi
%attr(0755,apache,apache) /var/www/cgi-bin/*.png
%attr(0755,root,root) %{_datadir}/%{name}-%{version}/db/*
%dir %attr(-,squid,squid)/var/log/%{name}
%attr(-,squid,squid)/var/log/%{name}/*
%config(noreplace) %{_sysconfdir}/squid/*
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}


%changelog
* Fri Dec 21 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.1-2mdv2008.1
+ Revision: 136303
- rebuilt against new build deps

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Oct 11 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.1-1mdv2008.1
+ Revision: 96985
- 1.2.1

  + Thierry Vignaud <tvignaud@mandriva.com>
    - s/Mandrake/Mandriva/

* Tue May 15 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.0-14mdv2008.0
+ Revision: 26874
- sync changes with the 1.2.0-13.1mdv2007.1 package:
  - fix the %%postun script and add some triggers so that
    /usr/share/squidGuard-[ver] doesn't get completely removed
    on an upgrade


* Wed Mar 07 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.0-13mdv2007.0
+ Revision: 134473
- Import squidGuard

* Wed Mar 07 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.0-13mdv2007.1
- bunzip patches

* Sun May 28 2006 Stefan van der Eijk <stefan@eijk.nu> 1.2.0-12mdk
- %%mkrel
- fix URL of source

* Sun Jan 01 2006 Mandriva Linux Team <http://www.mandrivaexpert.com/> 1.2.0-11mdk
- Rebuild

* Tue Apr 20 2004 Florin <florin@mandrakesoft.com> 1.2.0-10mdk
- fix the logrotate bug #9526

* Fri Apr 16 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.2.0-9mdk
- fix build

